#
# spec file for package patch2mail
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2008-2015 Christian Boltz
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           patch2mail
Version:        1.1.2
Release:        5.3
Summary:        Patch and package update notification via mail
License:        GPL-2.0-or-later
Group:          System/Packages
URL:            https://github.com/openSUSE/zypp-utils/tree/master/patch2mail
Source0:        %{name}-%{version}.tar.bz2
Source1:        %{name}.service
Source2:        %{name}.timer
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
BuildRequires:  systemd-rpm-macros
Requires:       /bin/hostname
Requires:       /bin/rm
Requires:       /usr/bin/xsltproc
Requires:       grep
Requires:       mail
Requires:       mktemp
Requires:       zypper
# detailed requirements:
#      zypper    # (>= 11.0) zypp-refresh-rapper, zypper
#      zypper    # (<= 10.3) zypp-checkpatches-wrapper
#      libxslt   # xsltproc [NOT autodetected, even if rpmlint thinks so]
#      coreutils # rm
#      net-tools # hostname

%description
patch2mail checks for available updates and sends a mail to root
if any patches or updated packages (configureable) are available.

%prep
%setup -q

%build

%install
%{__install} -d -m 0755 %{buildroot}%{_datadir}/%{name}
%{__install} -d -m 0755 %{buildroot}%{_fillupdir}/
%{__install} -D -m 0644 %{SOURCE1} %{buildroot}/%{_unitdir}/%{name}.service
%{__install} -D -m 0644 %{SOURCE2} %{buildroot}/%{_unitdir}/%{name}.timer
%{__install} -D -m 0755 patch2mail %{buildroot}%{_bindir}/patch2mail
%{__install} -m 0644 patch2mail.sysconfig %{buildroot}%{_fillupdir}/sysconfig.patch2mail

%{__install} -m 0644 patch2mail.xsl %{buildroot}%{_datadir}/%{name}/patch2mail.xsl
%if 0%{?suse_version} < 1030
	%{__install} -m 0644 patch2mail.xsl_10.2 %{buildroot}%{_datadir}/%{name}/patch2mail.xsl
%endif

%pre
%service_add_pre %{name}.service %{name}.timer

%preun
%service_del_preun %{name}.service %{name}.timer

%post
%{fillup_only -n patch2mail}
%service_add_post %{name}.service %{name}.timer

%postun
%service_del_postun %{name}.service %{name}.timer

%files
%defattr(-,root,root)
%{_bindir}/%{name}
%{_unitdir}/%{name}.service
%{_unitdir}/%{name}.timer
%{_datadir}/%{name}
%{_fillupdir}/sysconfig.patch2mail
%doc README COPYING

%changelog
* Fri Nov  3 2023 Martin Schreiner <martin.schreiner@suse.com>
- Migrate from cron to systemd-timers.
* Tue Aug 20 2019 kukuk@suse.de
- BuildRequire cron, as it contains now the cron directories
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Fri Nov 27 2015 opensuse@cboltz.de
- add github URL to spec
* Tue Nov 17 2015 opensuse@cboltz.de
- use zypp-refresh, not the (no longer existing) zypp-refresh-wrapper
  (boo#955207)
- version 1.1.2
* Wed Mar  7 2012 opensuse@cboltz.de
- add copyright header to spec
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sat Jun 25 2011 opensuse@cboltz.de
- use --non-interactive to avoid endless hanging zypper process
  on unknown repo signing keys
- version 1.1.1
* Sun Jun 19 2011 opensuse@cboltz.de
- updated summary to include package updates
- version 1.1
* Sun Apr  3 2011 opensuse@cboltz.de
- include note about patches affecting the package manager
- new sysconfig option PATCHES_ONLY - set to "no" to include package
  updates in the notification mail
- added handling for package updates in patch2mail and the xslt
* Tue Nov 23 2010 opensuse@cboltz.de
- version 1.0
  - brand-new feature: the package now contains a copy of the
    GPL ;-)) [bnc #655441]
  - tarball contains up-to-date specfile again
  - no code changes
* Thu Nov 18 2010 opensuse@cboltz.de
- spec file cosmetics: GPLv2+ instead of just GPL
* Mon Nov 15 2010 opensuse@cboltz.de
- spec file cleanup (using spec-cleaner)
* Thu Aug 20 2009 opensuse@cboltz.de
- spec file improvements (better Requires:) (by AdrianS)
* Sun Apr 12 2009 opensuse@cboltz.de
- version 0.9.5
* Wed Apr  8 2009 anschneider@exsuse.de
- added support for sysconfig
- use install instead of cp and mkdir
* Sun Dec 14 2008 opensuse@cboltz.de
- added %%dir for datadir to avoid "file listed twice" warning
* Tue Dec  9 2008 opensuse@cboltz.de
- some small output fixes
- enforce LANG=C to avoid charset problems in zypper output
- version 0.9.4
* Fri Nov 21 2008 opensuse@cboltz.de
- update for openSUSE 11.1 (zypper needs "lu -t patch" now)
- version 0.9.3
* Sun Jul 20 2008 opensuse@cboltz.de
- update for openSUSE 11.0 (scripts for older versions still included)
- require cron to ensure the script is running daily
- version 0.9.2
* Mon Feb 18 2008 opensuse@cboltz.de
- Initial SVN commit of patch2mail
- SVN: http://svn.opensuse.org/svn/zypp/trunk/tools/patch2mail
- version 0.9.1
